from os.path import abspath, dirname

from setuptools import setup

LONG_DESCRIPTION = open(dirname(abspath(__file__)) + "/README.md", "r").read()


setup(
    name="types-aiobotocore-lite",
    version="2.3.4",
    packages=["aiobotocore-stubs"],
    url="https://github.com/youtype/mypy_boto3_builder",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Type annotations for aiobotocore 2.3.4 generated with mypy-boto3-builder 7.7.2",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Typed",
    ],
    keywords=(
        "aiobotocore type-annotations aiobotocore-stubs botocore-stubs mypy typeshed autocomplete"
    ),
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    package_data={"aiobotocore-stubs": ["py.typed", "*.pyi", "*/*.pyi"]},
    python_requires=">=3.6",
    project_urls={
        "Documentation": "https://youtype.github.io/types_aiobotocore_docs/",
        "Source": "https://github.com/youtype/mypy_boto3_builder",
        "Tracker": "https://github.com/youtype/mypy_boto3_builder/issues",
    },
    install_requires=[
        "aiobotocore",
        "botocore-stubs",
        "typing-extensions>=4.1.0",
    ],
    extras_require={
        "all": [
            "types-aiobotocore-accessanalyzer>=2.3.0, <2.4.0",
            "types-aiobotocore-account>=2.3.0, <2.4.0",
            "types-aiobotocore-acm>=2.3.0, <2.4.0",
            "types-aiobotocore-acm-pca>=2.3.0, <2.4.0",
            "types-aiobotocore-alexaforbusiness>=2.3.0, <2.4.0",
            "types-aiobotocore-amp>=2.3.0, <2.4.0",
            "types-aiobotocore-amplify>=2.3.0, <2.4.0",
            "types-aiobotocore-amplifybackend>=2.3.0, <2.4.0",
            "types-aiobotocore-amplifyuibuilder>=2.3.0, <2.4.0",
            "types-aiobotocore-apigateway>=2.3.0, <2.4.0",
            "types-aiobotocore-apigatewaymanagementapi>=2.3.0, <2.4.0",
            "types-aiobotocore-apigatewayv2>=2.3.0, <2.4.0",
            "types-aiobotocore-appconfig>=2.3.0, <2.4.0",
            "types-aiobotocore-appconfigdata>=2.3.0, <2.4.0",
            "types-aiobotocore-appflow>=2.3.0, <2.4.0",
            "types-aiobotocore-appintegrations>=2.3.0, <2.4.0",
            "types-aiobotocore-application-autoscaling>=2.3.0, <2.4.0",
            "types-aiobotocore-application-insights>=2.3.0, <2.4.0",
            "types-aiobotocore-applicationcostprofiler>=2.3.0, <2.4.0",
            "types-aiobotocore-appmesh>=2.3.0, <2.4.0",
            "types-aiobotocore-apprunner>=2.3.0, <2.4.0",
            "types-aiobotocore-appstream>=2.3.0, <2.4.0",
            "types-aiobotocore-appsync>=2.3.0, <2.4.0",
            "types-aiobotocore-athena>=2.3.0, <2.4.0",
            "types-aiobotocore-auditmanager>=2.3.0, <2.4.0",
            "types-aiobotocore-autoscaling>=2.3.0, <2.4.0",
            "types-aiobotocore-autoscaling-plans>=2.3.0, <2.4.0",
            "types-aiobotocore-backup>=2.3.0, <2.4.0",
            "types-aiobotocore-backup-gateway>=2.3.0, <2.4.0",
            "types-aiobotocore-batch>=2.3.0, <2.4.0",
            "types-aiobotocore-billingconductor>=2.3.0, <2.4.0",
            "types-aiobotocore-braket>=2.3.0, <2.4.0",
            "types-aiobotocore-budgets>=2.3.0, <2.4.0",
            "types-aiobotocore-ce>=2.3.0, <2.4.0",
            "types-aiobotocore-chime>=2.3.0, <2.4.0",
            "types-aiobotocore-chime-sdk-identity>=2.3.0, <2.4.0",
            "types-aiobotocore-chime-sdk-meetings>=2.3.0, <2.4.0",
            "types-aiobotocore-chime-sdk-messaging>=2.3.0, <2.4.0",
            "types-aiobotocore-cloud9>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudcontrol>=2.3.0, <2.4.0",
            "types-aiobotocore-clouddirectory>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudformation>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudfront>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudhsm>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudhsmv2>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudsearch>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudsearchdomain>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudtrail>=2.3.0, <2.4.0",
            "types-aiobotocore-cloudwatch>=2.3.0, <2.4.0",
            "types-aiobotocore-codeartifact>=2.3.0, <2.4.0",
            "types-aiobotocore-codebuild>=2.3.0, <2.4.0",
            "types-aiobotocore-codecommit>=2.3.0, <2.4.0",
            "types-aiobotocore-codedeploy>=2.3.0, <2.4.0",
            "types-aiobotocore-codeguru-reviewer>=2.3.0, <2.4.0",
            "types-aiobotocore-codeguruprofiler>=2.3.0, <2.4.0",
            "types-aiobotocore-codepipeline>=2.3.0, <2.4.0",
            "types-aiobotocore-codestar>=2.3.0, <2.4.0",
            "types-aiobotocore-codestar-connections>=2.3.0, <2.4.0",
            "types-aiobotocore-codestar-notifications>=2.3.0, <2.4.0",
            "types-aiobotocore-cognito-identity>=2.3.0, <2.4.0",
            "types-aiobotocore-cognito-idp>=2.3.0, <2.4.0",
            "types-aiobotocore-cognito-sync>=2.3.0, <2.4.0",
            "types-aiobotocore-comprehend>=2.3.0, <2.4.0",
            "types-aiobotocore-comprehendmedical>=2.3.0, <2.4.0",
            "types-aiobotocore-compute-optimizer>=2.3.0, <2.4.0",
            "types-aiobotocore-config>=2.3.0, <2.4.0",
            "types-aiobotocore-connect>=2.3.0, <2.4.0",
            "types-aiobotocore-connect-contact-lens>=2.3.0, <2.4.0",
            "types-aiobotocore-connectparticipant>=2.3.0, <2.4.0",
            "types-aiobotocore-cur>=2.3.0, <2.4.0",
            "types-aiobotocore-customer-profiles>=2.3.0, <2.4.0",
            "types-aiobotocore-databrew>=2.3.0, <2.4.0",
            "types-aiobotocore-dataexchange>=2.3.0, <2.4.0",
            "types-aiobotocore-datapipeline>=2.3.0, <2.4.0",
            "types-aiobotocore-datasync>=2.3.0, <2.4.0",
            "types-aiobotocore-dax>=2.3.0, <2.4.0",
            "types-aiobotocore-detective>=2.3.0, <2.4.0",
            "types-aiobotocore-devicefarm>=2.3.0, <2.4.0",
            "types-aiobotocore-devops-guru>=2.3.0, <2.4.0",
            "types-aiobotocore-directconnect>=2.3.0, <2.4.0",
            "types-aiobotocore-discovery>=2.3.0, <2.4.0",
            "types-aiobotocore-dlm>=2.3.0, <2.4.0",
            "types-aiobotocore-dms>=2.3.0, <2.4.0",
            "types-aiobotocore-docdb>=2.3.0, <2.4.0",
            "types-aiobotocore-drs>=2.3.0, <2.4.0",
            "types-aiobotocore-ds>=2.3.0, <2.4.0",
            "types-aiobotocore-dynamodb>=2.3.0, <2.4.0",
            "types-aiobotocore-dynamodbstreams>=2.3.0, <2.4.0",
            "types-aiobotocore-ebs>=2.3.0, <2.4.0",
            "types-aiobotocore-ec2>=2.3.0, <2.4.0",
            "types-aiobotocore-ec2-instance-connect>=2.3.0, <2.4.0",
            "types-aiobotocore-ecr>=2.3.0, <2.4.0",
            "types-aiobotocore-ecr-public>=2.3.0, <2.4.0",
            "types-aiobotocore-ecs>=2.3.0, <2.4.0",
            "types-aiobotocore-efs>=2.3.0, <2.4.0",
            "types-aiobotocore-eks>=2.3.0, <2.4.0",
            "types-aiobotocore-elastic-inference>=2.3.0, <2.4.0",
            "types-aiobotocore-elasticache>=2.3.0, <2.4.0",
            "types-aiobotocore-elasticbeanstalk>=2.3.0, <2.4.0",
            "types-aiobotocore-elastictranscoder>=2.3.0, <2.4.0",
            "types-aiobotocore-elb>=2.3.0, <2.4.0",
            "types-aiobotocore-elbv2>=2.3.0, <2.4.0",
            "types-aiobotocore-emr>=2.3.0, <2.4.0",
            "types-aiobotocore-emr-containers>=2.3.0, <2.4.0",
            "types-aiobotocore-es>=2.3.0, <2.4.0",
            "types-aiobotocore-events>=2.3.0, <2.4.0",
            "types-aiobotocore-evidently>=2.3.0, <2.4.0",
            "types-aiobotocore-finspace>=2.3.0, <2.4.0",
            "types-aiobotocore-finspace-data>=2.3.0, <2.4.0",
            "types-aiobotocore-firehose>=2.3.0, <2.4.0",
            "types-aiobotocore-fis>=2.3.0, <2.4.0",
            "types-aiobotocore-fms>=2.3.0, <2.4.0",
            "types-aiobotocore-forecast>=2.3.0, <2.4.0",
            "types-aiobotocore-forecastquery>=2.3.0, <2.4.0",
            "types-aiobotocore-frauddetector>=2.3.0, <2.4.0",
            "types-aiobotocore-fsx>=2.3.0, <2.4.0",
            "types-aiobotocore-gamelift>=2.3.0, <2.4.0",
            "types-aiobotocore-glacier>=2.3.0, <2.4.0",
            "types-aiobotocore-globalaccelerator>=2.3.0, <2.4.0",
            "types-aiobotocore-glue>=2.3.0, <2.4.0",
            "types-aiobotocore-grafana>=2.3.0, <2.4.0",
            "types-aiobotocore-greengrass>=2.3.0, <2.4.0",
            "types-aiobotocore-greengrassv2>=2.3.0, <2.4.0",
            "types-aiobotocore-groundstation>=2.3.0, <2.4.0",
            "types-aiobotocore-guardduty>=2.3.0, <2.4.0",
            "types-aiobotocore-health>=2.3.0, <2.4.0",
            "types-aiobotocore-healthlake>=2.3.0, <2.4.0",
            "types-aiobotocore-honeycode>=2.3.0, <2.4.0",
            "types-aiobotocore-iam>=2.3.0, <2.4.0",
            "types-aiobotocore-identitystore>=2.3.0, <2.4.0",
            "types-aiobotocore-imagebuilder>=2.3.0, <2.4.0",
            "types-aiobotocore-importexport>=2.3.0, <2.4.0",
            "types-aiobotocore-inspector>=2.3.0, <2.4.0",
            "types-aiobotocore-inspector2>=2.3.0, <2.4.0",
            "types-aiobotocore-iot>=2.3.0, <2.4.0",
            "types-aiobotocore-iot-data>=2.3.0, <2.4.0",
            "types-aiobotocore-iot-jobs-data>=2.3.0, <2.4.0",
            "types-aiobotocore-iot1click-devices>=2.3.0, <2.4.0",
            "types-aiobotocore-iot1click-projects>=2.3.0, <2.4.0",
            "types-aiobotocore-iotanalytics>=2.3.0, <2.4.0",
            "types-aiobotocore-iotdeviceadvisor>=2.3.0, <2.4.0",
            "types-aiobotocore-iotevents>=2.3.0, <2.4.0",
            "types-aiobotocore-iotevents-data>=2.3.0, <2.4.0",
            "types-aiobotocore-iotfleethub>=2.3.0, <2.4.0",
            "types-aiobotocore-iotsecuretunneling>=2.3.0, <2.4.0",
            "types-aiobotocore-iotsitewise>=2.3.0, <2.4.0",
            "types-aiobotocore-iotthingsgraph>=2.3.0, <2.4.0",
            "types-aiobotocore-iottwinmaker>=2.3.0, <2.4.0",
            "types-aiobotocore-iotwireless>=2.3.0, <2.4.0",
            "types-aiobotocore-ivs>=2.3.0, <2.4.0",
            "types-aiobotocore-kafka>=2.3.0, <2.4.0",
            "types-aiobotocore-kafkaconnect>=2.3.0, <2.4.0",
            "types-aiobotocore-kendra>=2.3.0, <2.4.0",
            "types-aiobotocore-keyspaces>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesis>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesis-video-archived-media>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesis-video-media>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesis-video-signaling>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesisanalytics>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesisanalyticsv2>=2.3.0, <2.4.0",
            "types-aiobotocore-kinesisvideo>=2.3.0, <2.4.0",
            "types-aiobotocore-kms>=2.3.0, <2.4.0",
            "types-aiobotocore-lakeformation>=2.3.0, <2.4.0",
            "types-aiobotocore-lambda>=2.3.0, <2.4.0",
            "types-aiobotocore-lex-models>=2.3.0, <2.4.0",
            "types-aiobotocore-lex-runtime>=2.3.0, <2.4.0",
            "types-aiobotocore-lexv2-models>=2.3.0, <2.4.0",
            "types-aiobotocore-lexv2-runtime>=2.3.0, <2.4.0",
            "types-aiobotocore-license-manager>=2.3.0, <2.4.0",
            "types-aiobotocore-lightsail>=2.3.0, <2.4.0",
            "types-aiobotocore-location>=2.3.0, <2.4.0",
            "types-aiobotocore-logs>=2.3.0, <2.4.0",
            "types-aiobotocore-lookoutequipment>=2.3.0, <2.4.0",
            "types-aiobotocore-lookoutmetrics>=2.3.0, <2.4.0",
            "types-aiobotocore-lookoutvision>=2.3.0, <2.4.0",
            "types-aiobotocore-machinelearning>=2.3.0, <2.4.0",
            "types-aiobotocore-macie>=2.3.0, <2.4.0",
            "types-aiobotocore-macie2>=2.3.0, <2.4.0",
            "types-aiobotocore-managedblockchain>=2.3.0, <2.4.0",
            "types-aiobotocore-marketplace-catalog>=2.3.0, <2.4.0",
            "types-aiobotocore-marketplace-entitlement>=2.3.0, <2.4.0",
            "types-aiobotocore-marketplacecommerceanalytics>=2.3.0, <2.4.0",
            "types-aiobotocore-mediaconnect>=2.3.0, <2.4.0",
            "types-aiobotocore-mediaconvert>=2.3.0, <2.4.0",
            "types-aiobotocore-medialive>=2.3.0, <2.4.0",
            "types-aiobotocore-mediapackage>=2.3.0, <2.4.0",
            "types-aiobotocore-mediapackage-vod>=2.3.0, <2.4.0",
            "types-aiobotocore-mediastore>=2.3.0, <2.4.0",
            "types-aiobotocore-mediastore-data>=2.3.0, <2.4.0",
            "types-aiobotocore-mediatailor>=2.3.0, <2.4.0",
            "types-aiobotocore-memorydb>=2.3.0, <2.4.0",
            "types-aiobotocore-meteringmarketplace>=2.3.0, <2.4.0",
            "types-aiobotocore-mgh>=2.3.0, <2.4.0",
            "types-aiobotocore-mgn>=2.3.0, <2.4.0",
            "types-aiobotocore-migration-hub-refactor-spaces>=2.3.0, <2.4.0",
            "types-aiobotocore-migrationhub-config>=2.3.0, <2.4.0",
            "types-aiobotocore-migrationhubstrategy>=2.3.0, <2.4.0",
            "types-aiobotocore-mobile>=2.3.0, <2.4.0",
            "types-aiobotocore-mq>=2.3.0, <2.4.0",
            "types-aiobotocore-mturk>=2.3.0, <2.4.0",
            "types-aiobotocore-mwaa>=2.3.0, <2.4.0",
            "types-aiobotocore-neptune>=2.3.0, <2.4.0",
            "types-aiobotocore-network-firewall>=2.3.0, <2.4.0",
            "types-aiobotocore-networkmanager>=2.3.0, <2.4.0",
            "types-aiobotocore-nimble>=2.3.0, <2.4.0",
            "types-aiobotocore-opensearch>=2.3.0, <2.4.0",
            "types-aiobotocore-opsworks>=2.3.0, <2.4.0",
            "types-aiobotocore-opsworkscm>=2.3.0, <2.4.0",
            "types-aiobotocore-organizations>=2.3.0, <2.4.0",
            "types-aiobotocore-outposts>=2.3.0, <2.4.0",
            "types-aiobotocore-panorama>=2.3.0, <2.4.0",
            "types-aiobotocore-personalize>=2.3.0, <2.4.0",
            "types-aiobotocore-personalize-events>=2.3.0, <2.4.0",
            "types-aiobotocore-personalize-runtime>=2.3.0, <2.4.0",
            "types-aiobotocore-pi>=2.3.0, <2.4.0",
            "types-aiobotocore-pinpoint>=2.3.0, <2.4.0",
            "types-aiobotocore-pinpoint-email>=2.3.0, <2.4.0",
            "types-aiobotocore-pinpoint-sms-voice>=2.3.0, <2.4.0",
            "types-aiobotocore-polly>=2.3.0, <2.4.0",
            "types-aiobotocore-pricing>=2.3.0, <2.4.0",
            "types-aiobotocore-proton>=2.3.0, <2.4.0",
            "types-aiobotocore-qldb>=2.3.0, <2.4.0",
            "types-aiobotocore-qldb-session>=2.3.0, <2.4.0",
            "types-aiobotocore-quicksight>=2.3.0, <2.4.0",
            "types-aiobotocore-ram>=2.3.0, <2.4.0",
            "types-aiobotocore-rbin>=2.3.0, <2.4.0",
            "types-aiobotocore-rds>=2.3.0, <2.4.0",
            "types-aiobotocore-rds-data>=2.3.0, <2.4.0",
            "types-aiobotocore-redshift>=2.3.0, <2.4.0",
            "types-aiobotocore-redshift-data>=2.3.0, <2.4.0",
            "types-aiobotocore-rekognition>=2.3.0, <2.4.0",
            "types-aiobotocore-resiliencehub>=2.3.0, <2.4.0",
            "types-aiobotocore-resource-groups>=2.3.0, <2.4.0",
            "types-aiobotocore-resourcegroupstaggingapi>=2.3.0, <2.4.0",
            "types-aiobotocore-robomaker>=2.3.0, <2.4.0",
            "types-aiobotocore-route53>=2.3.0, <2.4.0",
            "types-aiobotocore-route53-recovery-cluster>=2.3.0, <2.4.0",
            "types-aiobotocore-route53-recovery-control-config>=2.3.0, <2.4.0",
            "types-aiobotocore-route53-recovery-readiness>=2.3.0, <2.4.0",
            "types-aiobotocore-route53domains>=2.3.0, <2.4.0",
            "types-aiobotocore-route53resolver>=2.3.0, <2.4.0",
            "types-aiobotocore-rum>=2.3.0, <2.4.0",
            "types-aiobotocore-s3>=2.3.0, <2.4.0",
            "types-aiobotocore-s3control>=2.3.0, <2.4.0",
            "types-aiobotocore-s3outposts>=2.3.0, <2.4.0",
            "types-aiobotocore-sagemaker>=2.3.0, <2.4.0",
            "types-aiobotocore-sagemaker-a2i-runtime>=2.3.0, <2.4.0",
            "types-aiobotocore-sagemaker-edge>=2.3.0, <2.4.0",
            "types-aiobotocore-sagemaker-featurestore-runtime>=2.3.0, <2.4.0",
            "types-aiobotocore-sagemaker-runtime>=2.3.0, <2.4.0",
            "types-aiobotocore-savingsplans>=2.3.0, <2.4.0",
            "types-aiobotocore-schemas>=2.3.0, <2.4.0",
            "types-aiobotocore-sdb>=2.3.0, <2.4.0",
            "types-aiobotocore-secretsmanager>=2.3.0, <2.4.0",
            "types-aiobotocore-securityhub>=2.3.0, <2.4.0",
            "types-aiobotocore-serverlessrepo>=2.3.0, <2.4.0",
            "types-aiobotocore-service-quotas>=2.3.0, <2.4.0",
            "types-aiobotocore-servicecatalog>=2.3.0, <2.4.0",
            "types-aiobotocore-servicecatalog-appregistry>=2.3.0, <2.4.0",
            "types-aiobotocore-servicediscovery>=2.3.0, <2.4.0",
            "types-aiobotocore-ses>=2.3.0, <2.4.0",
            "types-aiobotocore-sesv2>=2.3.0, <2.4.0",
            "types-aiobotocore-shield>=2.3.0, <2.4.0",
            "types-aiobotocore-signer>=2.3.0, <2.4.0",
            "types-aiobotocore-sms>=2.3.0, <2.4.0",
            "types-aiobotocore-sms-voice>=2.3.0, <2.4.0",
            "types-aiobotocore-snow-device-management>=2.3.0, <2.4.0",
            "types-aiobotocore-snowball>=2.3.0, <2.4.0",
            "types-aiobotocore-sns>=2.3.0, <2.4.0",
            "types-aiobotocore-sqs>=2.3.0, <2.4.0",
            "types-aiobotocore-ssm>=2.3.0, <2.4.0",
            "types-aiobotocore-ssm-contacts>=2.3.0, <2.4.0",
            "types-aiobotocore-ssm-incidents>=2.3.0, <2.4.0",
            "types-aiobotocore-sso>=2.3.0, <2.4.0",
            "types-aiobotocore-sso-admin>=2.3.0, <2.4.0",
            "types-aiobotocore-sso-oidc>=2.3.0, <2.4.0",
            "types-aiobotocore-stepfunctions>=2.3.0, <2.4.0",
            "types-aiobotocore-storagegateway>=2.3.0, <2.4.0",
            "types-aiobotocore-sts>=2.3.0, <2.4.0",
            "types-aiobotocore-support>=2.3.0, <2.4.0",
            "types-aiobotocore-swf>=2.3.0, <2.4.0",
            "types-aiobotocore-synthetics>=2.3.0, <2.4.0",
            "types-aiobotocore-textract>=2.3.0, <2.4.0",
            "types-aiobotocore-timestream-query>=2.3.0, <2.4.0",
            "types-aiobotocore-timestream-write>=2.3.0, <2.4.0",
            "types-aiobotocore-transcribe>=2.3.0, <2.4.0",
            "types-aiobotocore-transfer>=2.3.0, <2.4.0",
            "types-aiobotocore-translate>=2.3.0, <2.4.0",
            "types-aiobotocore-voice-id>=2.3.0, <2.4.0",
            "types-aiobotocore-waf>=2.3.0, <2.4.0",
            "types-aiobotocore-waf-regional>=2.3.0, <2.4.0",
            "types-aiobotocore-wafv2>=2.3.0, <2.4.0",
            "types-aiobotocore-wellarchitected>=2.3.0, <2.4.0",
            "types-aiobotocore-wisdom>=2.3.0, <2.4.0",
            "types-aiobotocore-workdocs>=2.3.0, <2.4.0",
            "types-aiobotocore-worklink>=2.3.0, <2.4.0",
            "types-aiobotocore-workmail>=2.3.0, <2.4.0",
            "types-aiobotocore-workmailmessageflow>=2.3.0, <2.4.0",
            "types-aiobotocore-workspaces>=2.3.0, <2.4.0",
            "types-aiobotocore-workspaces-web>=2.3.0, <2.4.0",
            "types-aiobotocore-xray>=2.3.0, <2.4.0",
        ],
        "essential": [
            "types-aiobotocore-cloudformation>=2.3.0, <2.4.0",
            "types-aiobotocore-dynamodb>=2.3.0, <2.4.0",
            "types-aiobotocore-ec2>=2.3.0, <2.4.0",
            "types-aiobotocore-lambda>=2.3.0, <2.4.0",
            "types-aiobotocore-rds>=2.3.0, <2.4.0",
            "types-aiobotocore-s3>=2.3.0, <2.4.0",
            "types-aiobotocore-sqs>=2.3.0, <2.4.0",
        ],
        "accessanalyzer": ["types-aiobotocore-accessanalyzer>=2.3.0, <2.4.0"],
        "account": ["types-aiobotocore-account>=2.3.0, <2.4.0"],
        "acm": ["types-aiobotocore-acm>=2.3.0, <2.4.0"],
        "acm-pca": ["types-aiobotocore-acm-pca>=2.3.0, <2.4.0"],
        "alexaforbusiness": ["types-aiobotocore-alexaforbusiness>=2.3.0, <2.4.0"],
        "amp": ["types-aiobotocore-amp>=2.3.0, <2.4.0"],
        "amplify": ["types-aiobotocore-amplify>=2.3.0, <2.4.0"],
        "amplifybackend": ["types-aiobotocore-amplifybackend>=2.3.0, <2.4.0"],
        "amplifyuibuilder": ["types-aiobotocore-amplifyuibuilder>=2.3.0, <2.4.0"],
        "apigateway": ["types-aiobotocore-apigateway>=2.3.0, <2.4.0"],
        "apigatewaymanagementapi": ["types-aiobotocore-apigatewaymanagementapi>=2.3.0, <2.4.0"],
        "apigatewayv2": ["types-aiobotocore-apigatewayv2>=2.3.0, <2.4.0"],
        "appconfig": ["types-aiobotocore-appconfig>=2.3.0, <2.4.0"],
        "appconfigdata": ["types-aiobotocore-appconfigdata>=2.3.0, <2.4.0"],
        "appflow": ["types-aiobotocore-appflow>=2.3.0, <2.4.0"],
        "appintegrations": ["types-aiobotocore-appintegrations>=2.3.0, <2.4.0"],
        "application-autoscaling": ["types-aiobotocore-application-autoscaling>=2.3.0, <2.4.0"],
        "application-insights": ["types-aiobotocore-application-insights>=2.3.0, <2.4.0"],
        "applicationcostprofiler": ["types-aiobotocore-applicationcostprofiler>=2.3.0, <2.4.0"],
        "appmesh": ["types-aiobotocore-appmesh>=2.3.0, <2.4.0"],
        "apprunner": ["types-aiobotocore-apprunner>=2.3.0, <2.4.0"],
        "appstream": ["types-aiobotocore-appstream>=2.3.0, <2.4.0"],
        "appsync": ["types-aiobotocore-appsync>=2.3.0, <2.4.0"],
        "athena": ["types-aiobotocore-athena>=2.3.0, <2.4.0"],
        "auditmanager": ["types-aiobotocore-auditmanager>=2.3.0, <2.4.0"],
        "autoscaling": ["types-aiobotocore-autoscaling>=2.3.0, <2.4.0"],
        "autoscaling-plans": ["types-aiobotocore-autoscaling-plans>=2.3.0, <2.4.0"],
        "backup": ["types-aiobotocore-backup>=2.3.0, <2.4.0"],
        "backup-gateway": ["types-aiobotocore-backup-gateway>=2.3.0, <2.4.0"],
        "batch": ["types-aiobotocore-batch>=2.3.0, <2.4.0"],
        "billingconductor": ["types-aiobotocore-billingconductor>=2.3.0, <2.4.0"],
        "braket": ["types-aiobotocore-braket>=2.3.0, <2.4.0"],
        "budgets": ["types-aiobotocore-budgets>=2.3.0, <2.4.0"],
        "ce": ["types-aiobotocore-ce>=2.3.0, <2.4.0"],
        "chime": ["types-aiobotocore-chime>=2.3.0, <2.4.0"],
        "chime-sdk-identity": ["types-aiobotocore-chime-sdk-identity>=2.3.0, <2.4.0"],
        "chime-sdk-meetings": ["types-aiobotocore-chime-sdk-meetings>=2.3.0, <2.4.0"],
        "chime-sdk-messaging": ["types-aiobotocore-chime-sdk-messaging>=2.3.0, <2.4.0"],
        "cloud9": ["types-aiobotocore-cloud9>=2.3.0, <2.4.0"],
        "cloudcontrol": ["types-aiobotocore-cloudcontrol>=2.3.0, <2.4.0"],
        "clouddirectory": ["types-aiobotocore-clouddirectory>=2.3.0, <2.4.0"],
        "cloudformation": ["types-aiobotocore-cloudformation>=2.3.0, <2.4.0"],
        "cloudfront": ["types-aiobotocore-cloudfront>=2.3.0, <2.4.0"],
        "cloudhsm": ["types-aiobotocore-cloudhsm>=2.3.0, <2.4.0"],
        "cloudhsmv2": ["types-aiobotocore-cloudhsmv2>=2.3.0, <2.4.0"],
        "cloudsearch": ["types-aiobotocore-cloudsearch>=2.3.0, <2.4.0"],
        "cloudsearchdomain": ["types-aiobotocore-cloudsearchdomain>=2.3.0, <2.4.0"],
        "cloudtrail": ["types-aiobotocore-cloudtrail>=2.3.0, <2.4.0"],
        "cloudwatch": ["types-aiobotocore-cloudwatch>=2.3.0, <2.4.0"],
        "codeartifact": ["types-aiobotocore-codeartifact>=2.3.0, <2.4.0"],
        "codebuild": ["types-aiobotocore-codebuild>=2.3.0, <2.4.0"],
        "codecommit": ["types-aiobotocore-codecommit>=2.3.0, <2.4.0"],
        "codedeploy": ["types-aiobotocore-codedeploy>=2.3.0, <2.4.0"],
        "codeguru-reviewer": ["types-aiobotocore-codeguru-reviewer>=2.3.0, <2.4.0"],
        "codeguruprofiler": ["types-aiobotocore-codeguruprofiler>=2.3.0, <2.4.0"],
        "codepipeline": ["types-aiobotocore-codepipeline>=2.3.0, <2.4.0"],
        "codestar": ["types-aiobotocore-codestar>=2.3.0, <2.4.0"],
        "codestar-connections": ["types-aiobotocore-codestar-connections>=2.3.0, <2.4.0"],
        "codestar-notifications": ["types-aiobotocore-codestar-notifications>=2.3.0, <2.4.0"],
        "cognito-identity": ["types-aiobotocore-cognito-identity>=2.3.0, <2.4.0"],
        "cognito-idp": ["types-aiobotocore-cognito-idp>=2.3.0, <2.4.0"],
        "cognito-sync": ["types-aiobotocore-cognito-sync>=2.3.0, <2.4.0"],
        "comprehend": ["types-aiobotocore-comprehend>=2.3.0, <2.4.0"],
        "comprehendmedical": ["types-aiobotocore-comprehendmedical>=2.3.0, <2.4.0"],
        "compute-optimizer": ["types-aiobotocore-compute-optimizer>=2.3.0, <2.4.0"],
        "config": ["types-aiobotocore-config>=2.3.0, <2.4.0"],
        "connect": ["types-aiobotocore-connect>=2.3.0, <2.4.0"],
        "connect-contact-lens": ["types-aiobotocore-connect-contact-lens>=2.3.0, <2.4.0"],
        "connectparticipant": ["types-aiobotocore-connectparticipant>=2.3.0, <2.4.0"],
        "cur": ["types-aiobotocore-cur>=2.3.0, <2.4.0"],
        "customer-profiles": ["types-aiobotocore-customer-profiles>=2.3.0, <2.4.0"],
        "databrew": ["types-aiobotocore-databrew>=2.3.0, <2.4.0"],
        "dataexchange": ["types-aiobotocore-dataexchange>=2.3.0, <2.4.0"],
        "datapipeline": ["types-aiobotocore-datapipeline>=2.3.0, <2.4.0"],
        "datasync": ["types-aiobotocore-datasync>=2.3.0, <2.4.0"],
        "dax": ["types-aiobotocore-dax>=2.3.0, <2.4.0"],
        "detective": ["types-aiobotocore-detective>=2.3.0, <2.4.0"],
        "devicefarm": ["types-aiobotocore-devicefarm>=2.3.0, <2.4.0"],
        "devops-guru": ["types-aiobotocore-devops-guru>=2.3.0, <2.4.0"],
        "directconnect": ["types-aiobotocore-directconnect>=2.3.0, <2.4.0"],
        "discovery": ["types-aiobotocore-discovery>=2.3.0, <2.4.0"],
        "dlm": ["types-aiobotocore-dlm>=2.3.0, <2.4.0"],
        "dms": ["types-aiobotocore-dms>=2.3.0, <2.4.0"],
        "docdb": ["types-aiobotocore-docdb>=2.3.0, <2.4.0"],
        "drs": ["types-aiobotocore-drs>=2.3.0, <2.4.0"],
        "ds": ["types-aiobotocore-ds>=2.3.0, <2.4.0"],
        "dynamodb": ["types-aiobotocore-dynamodb>=2.3.0, <2.4.0"],
        "dynamodbstreams": ["types-aiobotocore-dynamodbstreams>=2.3.0, <2.4.0"],
        "ebs": ["types-aiobotocore-ebs>=2.3.0, <2.4.0"],
        "ec2": ["types-aiobotocore-ec2>=2.3.0, <2.4.0"],
        "ec2-instance-connect": ["types-aiobotocore-ec2-instance-connect>=2.3.0, <2.4.0"],
        "ecr": ["types-aiobotocore-ecr>=2.3.0, <2.4.0"],
        "ecr-public": ["types-aiobotocore-ecr-public>=2.3.0, <2.4.0"],
        "ecs": ["types-aiobotocore-ecs>=2.3.0, <2.4.0"],
        "efs": ["types-aiobotocore-efs>=2.3.0, <2.4.0"],
        "eks": ["types-aiobotocore-eks>=2.3.0, <2.4.0"],
        "elastic-inference": ["types-aiobotocore-elastic-inference>=2.3.0, <2.4.0"],
        "elasticache": ["types-aiobotocore-elasticache>=2.3.0, <2.4.0"],
        "elasticbeanstalk": ["types-aiobotocore-elasticbeanstalk>=2.3.0, <2.4.0"],
        "elastictranscoder": ["types-aiobotocore-elastictranscoder>=2.3.0, <2.4.0"],
        "elb": ["types-aiobotocore-elb>=2.3.0, <2.4.0"],
        "elbv2": ["types-aiobotocore-elbv2>=2.3.0, <2.4.0"],
        "emr": ["types-aiobotocore-emr>=2.3.0, <2.4.0"],
        "emr-containers": ["types-aiobotocore-emr-containers>=2.3.0, <2.4.0"],
        "es": ["types-aiobotocore-es>=2.3.0, <2.4.0"],
        "events": ["types-aiobotocore-events>=2.3.0, <2.4.0"],
        "evidently": ["types-aiobotocore-evidently>=2.3.0, <2.4.0"],
        "finspace": ["types-aiobotocore-finspace>=2.3.0, <2.4.0"],
        "finspace-data": ["types-aiobotocore-finspace-data>=2.3.0, <2.4.0"],
        "firehose": ["types-aiobotocore-firehose>=2.3.0, <2.4.0"],
        "fis": ["types-aiobotocore-fis>=2.3.0, <2.4.0"],
        "fms": ["types-aiobotocore-fms>=2.3.0, <2.4.0"],
        "forecast": ["types-aiobotocore-forecast>=2.3.0, <2.4.0"],
        "forecastquery": ["types-aiobotocore-forecastquery>=2.3.0, <2.4.0"],
        "frauddetector": ["types-aiobotocore-frauddetector>=2.3.0, <2.4.0"],
        "fsx": ["types-aiobotocore-fsx>=2.3.0, <2.4.0"],
        "gamelift": ["types-aiobotocore-gamelift>=2.3.0, <2.4.0"],
        "glacier": ["types-aiobotocore-glacier>=2.3.0, <2.4.0"],
        "globalaccelerator": ["types-aiobotocore-globalaccelerator>=2.3.0, <2.4.0"],
        "glue": ["types-aiobotocore-glue>=2.3.0, <2.4.0"],
        "grafana": ["types-aiobotocore-grafana>=2.3.0, <2.4.0"],
        "greengrass": ["types-aiobotocore-greengrass>=2.3.0, <2.4.0"],
        "greengrassv2": ["types-aiobotocore-greengrassv2>=2.3.0, <2.4.0"],
        "groundstation": ["types-aiobotocore-groundstation>=2.3.0, <2.4.0"],
        "guardduty": ["types-aiobotocore-guardduty>=2.3.0, <2.4.0"],
        "health": ["types-aiobotocore-health>=2.3.0, <2.4.0"],
        "healthlake": ["types-aiobotocore-healthlake>=2.3.0, <2.4.0"],
        "honeycode": ["types-aiobotocore-honeycode>=2.3.0, <2.4.0"],
        "iam": ["types-aiobotocore-iam>=2.3.0, <2.4.0"],
        "identitystore": ["types-aiobotocore-identitystore>=2.3.0, <2.4.0"],
        "imagebuilder": ["types-aiobotocore-imagebuilder>=2.3.0, <2.4.0"],
        "importexport": ["types-aiobotocore-importexport>=2.3.0, <2.4.0"],
        "inspector": ["types-aiobotocore-inspector>=2.3.0, <2.4.0"],
        "inspector2": ["types-aiobotocore-inspector2>=2.3.0, <2.4.0"],
        "iot": ["types-aiobotocore-iot>=2.3.0, <2.4.0"],
        "iot-data": ["types-aiobotocore-iot-data>=2.3.0, <2.4.0"],
        "iot-jobs-data": ["types-aiobotocore-iot-jobs-data>=2.3.0, <2.4.0"],
        "iot1click-devices": ["types-aiobotocore-iot1click-devices>=2.3.0, <2.4.0"],
        "iot1click-projects": ["types-aiobotocore-iot1click-projects>=2.3.0, <2.4.0"],
        "iotanalytics": ["types-aiobotocore-iotanalytics>=2.3.0, <2.4.0"],
        "iotdeviceadvisor": ["types-aiobotocore-iotdeviceadvisor>=2.3.0, <2.4.0"],
        "iotevents": ["types-aiobotocore-iotevents>=2.3.0, <2.4.0"],
        "iotevents-data": ["types-aiobotocore-iotevents-data>=2.3.0, <2.4.0"],
        "iotfleethub": ["types-aiobotocore-iotfleethub>=2.3.0, <2.4.0"],
        "iotsecuretunneling": ["types-aiobotocore-iotsecuretunneling>=2.3.0, <2.4.0"],
        "iotsitewise": ["types-aiobotocore-iotsitewise>=2.3.0, <2.4.0"],
        "iotthingsgraph": ["types-aiobotocore-iotthingsgraph>=2.3.0, <2.4.0"],
        "iottwinmaker": ["types-aiobotocore-iottwinmaker>=2.3.0, <2.4.0"],
        "iotwireless": ["types-aiobotocore-iotwireless>=2.3.0, <2.4.0"],
        "ivs": ["types-aiobotocore-ivs>=2.3.0, <2.4.0"],
        "kafka": ["types-aiobotocore-kafka>=2.3.0, <2.4.0"],
        "kafkaconnect": ["types-aiobotocore-kafkaconnect>=2.3.0, <2.4.0"],
        "kendra": ["types-aiobotocore-kendra>=2.3.0, <2.4.0"],
        "keyspaces": ["types-aiobotocore-keyspaces>=2.3.0, <2.4.0"],
        "kinesis": ["types-aiobotocore-kinesis>=2.3.0, <2.4.0"],
        "kinesis-video-archived-media": [
            "types-aiobotocore-kinesis-video-archived-media>=2.3.0, <2.4.0"
        ],
        "kinesis-video-media": ["types-aiobotocore-kinesis-video-media>=2.3.0, <2.4.0"],
        "kinesis-video-signaling": ["types-aiobotocore-kinesis-video-signaling>=2.3.0, <2.4.0"],
        "kinesisanalytics": ["types-aiobotocore-kinesisanalytics>=2.3.0, <2.4.0"],
        "kinesisanalyticsv2": ["types-aiobotocore-kinesisanalyticsv2>=2.3.0, <2.4.0"],
        "kinesisvideo": ["types-aiobotocore-kinesisvideo>=2.3.0, <2.4.0"],
        "kms": ["types-aiobotocore-kms>=2.3.0, <2.4.0"],
        "lakeformation": ["types-aiobotocore-lakeformation>=2.3.0, <2.4.0"],
        "lambda": ["types-aiobotocore-lambda>=2.3.0, <2.4.0"],
        "lex-models": ["types-aiobotocore-lex-models>=2.3.0, <2.4.0"],
        "lex-runtime": ["types-aiobotocore-lex-runtime>=2.3.0, <2.4.0"],
        "lexv2-models": ["types-aiobotocore-lexv2-models>=2.3.0, <2.4.0"],
        "lexv2-runtime": ["types-aiobotocore-lexv2-runtime>=2.3.0, <2.4.0"],
        "license-manager": ["types-aiobotocore-license-manager>=2.3.0, <2.4.0"],
        "lightsail": ["types-aiobotocore-lightsail>=2.3.0, <2.4.0"],
        "location": ["types-aiobotocore-location>=2.3.0, <2.4.0"],
        "logs": ["types-aiobotocore-logs>=2.3.0, <2.4.0"],
        "lookoutequipment": ["types-aiobotocore-lookoutequipment>=2.3.0, <2.4.0"],
        "lookoutmetrics": ["types-aiobotocore-lookoutmetrics>=2.3.0, <2.4.0"],
        "lookoutvision": ["types-aiobotocore-lookoutvision>=2.3.0, <2.4.0"],
        "machinelearning": ["types-aiobotocore-machinelearning>=2.3.0, <2.4.0"],
        "macie": ["types-aiobotocore-macie>=2.3.0, <2.4.0"],
        "macie2": ["types-aiobotocore-macie2>=2.3.0, <2.4.0"],
        "managedblockchain": ["types-aiobotocore-managedblockchain>=2.3.0, <2.4.0"],
        "marketplace-catalog": ["types-aiobotocore-marketplace-catalog>=2.3.0, <2.4.0"],
        "marketplace-entitlement": ["types-aiobotocore-marketplace-entitlement>=2.3.0, <2.4.0"],
        "marketplacecommerceanalytics": [
            "types-aiobotocore-marketplacecommerceanalytics>=2.3.0, <2.4.0"
        ],
        "mediaconnect": ["types-aiobotocore-mediaconnect>=2.3.0, <2.4.0"],
        "mediaconvert": ["types-aiobotocore-mediaconvert>=2.3.0, <2.4.0"],
        "medialive": ["types-aiobotocore-medialive>=2.3.0, <2.4.0"],
        "mediapackage": ["types-aiobotocore-mediapackage>=2.3.0, <2.4.0"],
        "mediapackage-vod": ["types-aiobotocore-mediapackage-vod>=2.3.0, <2.4.0"],
        "mediastore": ["types-aiobotocore-mediastore>=2.3.0, <2.4.0"],
        "mediastore-data": ["types-aiobotocore-mediastore-data>=2.3.0, <2.4.0"],
        "mediatailor": ["types-aiobotocore-mediatailor>=2.3.0, <2.4.0"],
        "memorydb": ["types-aiobotocore-memorydb>=2.3.0, <2.4.0"],
        "meteringmarketplace": ["types-aiobotocore-meteringmarketplace>=2.3.0, <2.4.0"],
        "mgh": ["types-aiobotocore-mgh>=2.3.0, <2.4.0"],
        "mgn": ["types-aiobotocore-mgn>=2.3.0, <2.4.0"],
        "migration-hub-refactor-spaces": [
            "types-aiobotocore-migration-hub-refactor-spaces>=2.3.0, <2.4.0"
        ],
        "migrationhub-config": ["types-aiobotocore-migrationhub-config>=2.3.0, <2.4.0"],
        "migrationhubstrategy": ["types-aiobotocore-migrationhubstrategy>=2.3.0, <2.4.0"],
        "mobile": ["types-aiobotocore-mobile>=2.3.0, <2.4.0"],
        "mq": ["types-aiobotocore-mq>=2.3.0, <2.4.0"],
        "mturk": ["types-aiobotocore-mturk>=2.3.0, <2.4.0"],
        "mwaa": ["types-aiobotocore-mwaa>=2.3.0, <2.4.0"],
        "neptune": ["types-aiobotocore-neptune>=2.3.0, <2.4.0"],
        "network-firewall": ["types-aiobotocore-network-firewall>=2.3.0, <2.4.0"],
        "networkmanager": ["types-aiobotocore-networkmanager>=2.3.0, <2.4.0"],
        "nimble": ["types-aiobotocore-nimble>=2.3.0, <2.4.0"],
        "opensearch": ["types-aiobotocore-opensearch>=2.3.0, <2.4.0"],
        "opsworks": ["types-aiobotocore-opsworks>=2.3.0, <2.4.0"],
        "opsworkscm": ["types-aiobotocore-opsworkscm>=2.3.0, <2.4.0"],
        "organizations": ["types-aiobotocore-organizations>=2.3.0, <2.4.0"],
        "outposts": ["types-aiobotocore-outposts>=2.3.0, <2.4.0"],
        "panorama": ["types-aiobotocore-panorama>=2.3.0, <2.4.0"],
        "personalize": ["types-aiobotocore-personalize>=2.3.0, <2.4.0"],
        "personalize-events": ["types-aiobotocore-personalize-events>=2.3.0, <2.4.0"],
        "personalize-runtime": ["types-aiobotocore-personalize-runtime>=2.3.0, <2.4.0"],
        "pi": ["types-aiobotocore-pi>=2.3.0, <2.4.0"],
        "pinpoint": ["types-aiobotocore-pinpoint>=2.3.0, <2.4.0"],
        "pinpoint-email": ["types-aiobotocore-pinpoint-email>=2.3.0, <2.4.0"],
        "pinpoint-sms-voice": ["types-aiobotocore-pinpoint-sms-voice>=2.3.0, <2.4.0"],
        "polly": ["types-aiobotocore-polly>=2.3.0, <2.4.0"],
        "pricing": ["types-aiobotocore-pricing>=2.3.0, <2.4.0"],
        "proton": ["types-aiobotocore-proton>=2.3.0, <2.4.0"],
        "qldb": ["types-aiobotocore-qldb>=2.3.0, <2.4.0"],
        "qldb-session": ["types-aiobotocore-qldb-session>=2.3.0, <2.4.0"],
        "quicksight": ["types-aiobotocore-quicksight>=2.3.0, <2.4.0"],
        "ram": ["types-aiobotocore-ram>=2.3.0, <2.4.0"],
        "rbin": ["types-aiobotocore-rbin>=2.3.0, <2.4.0"],
        "rds": ["types-aiobotocore-rds>=2.3.0, <2.4.0"],
        "rds-data": ["types-aiobotocore-rds-data>=2.3.0, <2.4.0"],
        "redshift": ["types-aiobotocore-redshift>=2.3.0, <2.4.0"],
        "redshift-data": ["types-aiobotocore-redshift-data>=2.3.0, <2.4.0"],
        "rekognition": ["types-aiobotocore-rekognition>=2.3.0, <2.4.0"],
        "resiliencehub": ["types-aiobotocore-resiliencehub>=2.3.0, <2.4.0"],
        "resource-groups": ["types-aiobotocore-resource-groups>=2.3.0, <2.4.0"],
        "resourcegroupstaggingapi": ["types-aiobotocore-resourcegroupstaggingapi>=2.3.0, <2.4.0"],
        "robomaker": ["types-aiobotocore-robomaker>=2.3.0, <2.4.0"],
        "route53": ["types-aiobotocore-route53>=2.3.0, <2.4.0"],
        "route53-recovery-cluster": ["types-aiobotocore-route53-recovery-cluster>=2.3.0, <2.4.0"],
        "route53-recovery-control-config": [
            "types-aiobotocore-route53-recovery-control-config>=2.3.0, <2.4.0"
        ],
        "route53-recovery-readiness": [
            "types-aiobotocore-route53-recovery-readiness>=2.3.0, <2.4.0"
        ],
        "route53domains": ["types-aiobotocore-route53domains>=2.3.0, <2.4.0"],
        "route53resolver": ["types-aiobotocore-route53resolver>=2.3.0, <2.4.0"],
        "rum": ["types-aiobotocore-rum>=2.3.0, <2.4.0"],
        "s3": ["types-aiobotocore-s3>=2.3.0, <2.4.0"],
        "s3control": ["types-aiobotocore-s3control>=2.3.0, <2.4.0"],
        "s3outposts": ["types-aiobotocore-s3outposts>=2.3.0, <2.4.0"],
        "sagemaker": ["types-aiobotocore-sagemaker>=2.3.0, <2.4.0"],
        "sagemaker-a2i-runtime": ["types-aiobotocore-sagemaker-a2i-runtime>=2.3.0, <2.4.0"],
        "sagemaker-edge": ["types-aiobotocore-sagemaker-edge>=2.3.0, <2.4.0"],
        "sagemaker-featurestore-runtime": [
            "types-aiobotocore-sagemaker-featurestore-runtime>=2.3.0, <2.4.0"
        ],
        "sagemaker-runtime": ["types-aiobotocore-sagemaker-runtime>=2.3.0, <2.4.0"],
        "savingsplans": ["types-aiobotocore-savingsplans>=2.3.0, <2.4.0"],
        "schemas": ["types-aiobotocore-schemas>=2.3.0, <2.4.0"],
        "sdb": ["types-aiobotocore-sdb>=2.3.0, <2.4.0"],
        "secretsmanager": ["types-aiobotocore-secretsmanager>=2.3.0, <2.4.0"],
        "securityhub": ["types-aiobotocore-securityhub>=2.3.0, <2.4.0"],
        "serverlessrepo": ["types-aiobotocore-serverlessrepo>=2.3.0, <2.4.0"],
        "service-quotas": ["types-aiobotocore-service-quotas>=2.3.0, <2.4.0"],
        "servicecatalog": ["types-aiobotocore-servicecatalog>=2.3.0, <2.4.0"],
        "servicecatalog-appregistry": [
            "types-aiobotocore-servicecatalog-appregistry>=2.3.0, <2.4.0"
        ],
        "servicediscovery": ["types-aiobotocore-servicediscovery>=2.3.0, <2.4.0"],
        "ses": ["types-aiobotocore-ses>=2.3.0, <2.4.0"],
        "sesv2": ["types-aiobotocore-sesv2>=2.3.0, <2.4.0"],
        "shield": ["types-aiobotocore-shield>=2.3.0, <2.4.0"],
        "signer": ["types-aiobotocore-signer>=2.3.0, <2.4.0"],
        "sms": ["types-aiobotocore-sms>=2.3.0, <2.4.0"],
        "sms-voice": ["types-aiobotocore-sms-voice>=2.3.0, <2.4.0"],
        "snow-device-management": ["types-aiobotocore-snow-device-management>=2.3.0, <2.4.0"],
        "snowball": ["types-aiobotocore-snowball>=2.3.0, <2.4.0"],
        "sns": ["types-aiobotocore-sns>=2.3.0, <2.4.0"],
        "sqs": ["types-aiobotocore-sqs>=2.3.0, <2.4.0"],
        "ssm": ["types-aiobotocore-ssm>=2.3.0, <2.4.0"],
        "ssm-contacts": ["types-aiobotocore-ssm-contacts>=2.3.0, <2.4.0"],
        "ssm-incidents": ["types-aiobotocore-ssm-incidents>=2.3.0, <2.4.0"],
        "sso": ["types-aiobotocore-sso>=2.3.0, <2.4.0"],
        "sso-admin": ["types-aiobotocore-sso-admin>=2.3.0, <2.4.0"],
        "sso-oidc": ["types-aiobotocore-sso-oidc>=2.3.0, <2.4.0"],
        "stepfunctions": ["types-aiobotocore-stepfunctions>=2.3.0, <2.4.0"],
        "storagegateway": ["types-aiobotocore-storagegateway>=2.3.0, <2.4.0"],
        "sts": ["types-aiobotocore-sts>=2.3.0, <2.4.0"],
        "support": ["types-aiobotocore-support>=2.3.0, <2.4.0"],
        "swf": ["types-aiobotocore-swf>=2.3.0, <2.4.0"],
        "synthetics": ["types-aiobotocore-synthetics>=2.3.0, <2.4.0"],
        "textract": ["types-aiobotocore-textract>=2.3.0, <2.4.0"],
        "timestream-query": ["types-aiobotocore-timestream-query>=2.3.0, <2.4.0"],
        "timestream-write": ["types-aiobotocore-timestream-write>=2.3.0, <2.4.0"],
        "transcribe": ["types-aiobotocore-transcribe>=2.3.0, <2.4.0"],
        "transfer": ["types-aiobotocore-transfer>=2.3.0, <2.4.0"],
        "translate": ["types-aiobotocore-translate>=2.3.0, <2.4.0"],
        "voice-id": ["types-aiobotocore-voice-id>=2.3.0, <2.4.0"],
        "waf": ["types-aiobotocore-waf>=2.3.0, <2.4.0"],
        "waf-regional": ["types-aiobotocore-waf-regional>=2.3.0, <2.4.0"],
        "wafv2": ["types-aiobotocore-wafv2>=2.3.0, <2.4.0"],
        "wellarchitected": ["types-aiobotocore-wellarchitected>=2.3.0, <2.4.0"],
        "wisdom": ["types-aiobotocore-wisdom>=2.3.0, <2.4.0"],
        "workdocs": ["types-aiobotocore-workdocs>=2.3.0, <2.4.0"],
        "worklink": ["types-aiobotocore-worklink>=2.3.0, <2.4.0"],
        "workmail": ["types-aiobotocore-workmail>=2.3.0, <2.4.0"],
        "workmailmessageflow": ["types-aiobotocore-workmailmessageflow>=2.3.0, <2.4.0"],
        "workspaces": ["types-aiobotocore-workspaces>=2.3.0, <2.4.0"],
        "workspaces-web": ["types-aiobotocore-workspaces-web>=2.3.0, <2.4.0"],
        "xray": ["types-aiobotocore-xray>=2.3.0, <2.4.0"],
    },
    zip_safe=False,
)
